@@ -23,6 +23,8 @@
 #include <QPrintDialog>
 #include <QSettings>
 #include <QTextStream>
+#include <QDesktopServices>
+#include <QTextCodec>
 
 
 #include "poppler-qt4.h"
@@ -30,7 +32,7 @@
 #define SYNCTEX_GZ_EXT ".synctex.gz"
 #define SYNCTEX_EXT ".synctex"
 
-PdfViewer::PdfViewer( const QString fileName, const QString externalCommand, const QString ghostscriptCommand, const QString psize,const QKeySequence edfocus,QWidget* parent, Qt::WFlags flags)
+PdfViewer::PdfViewer( const QString fileName, const QString externalCommand, const QString ghostscriptCommand, const QString psize,const QKeySequence edfocus,const QString SpellLang,QWidget* parent, Qt::WFlags flags)
     : QMainWindow( parent, flags )
 {
 setWindowTitle("Texmaker : pdf preview");
@@ -56,6 +58,7 @@ move(x,y);
 windowstate=config->value("MainWindowState").toByteArray();
 config->endGroup();
 
+spell_lang=SpellLang;
 KeySequenceEditorFocus=edfocus;
 setCorner(Qt::TopLeftCorner, Qt::LeftDockWidgetArea);
 canDisplayPixmap=false;
@@ -241,6 +244,9 @@ toolBar->addAction(printAct);
 externAct = new QAction(QIcon(":/images/viewpdf.png"), tr("External Viewer"), this);
 toolBar->addAction(externAct);
 
+checkerAct = new QAction(QIcon(":/images/pdfchecker.png"), tr("Check Spelling and Grammar on this page"), this);
+toolBar->addAction(checkerAct);
+
 searchLineEdit->setEnabled(false);
 findButton->setEnabled(false);
 scaleComboBox->setEnabled(false);
@@ -354,6 +360,9 @@ if (doc!=0)
     if (showingListPages) ShowListPages();
     else ShowStructure();
     gotoPage(currentPage);
+    disconnect(scrollArea,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
+    if (scrollArea->horizontalScrollBar()->isVisible())  scrollArea->horizontalScrollBar()->setValue(lastHpos);
+    connect(scrollArea,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
     } 
     else 
       {
@@ -565,6 +574,7 @@ connect(historyBackAct, SIGNAL(triggered()), this, SLOT(historyBack()));
 connect(historyForwardAct, SIGNAL(triggered()), this, SLOT(historyForward()));
 connect(printAct, SIGNAL(triggered()), this, SLOT(printPdf()));
 connect(externAct, SIGNAL(triggered()), this, SLOT(runExternalViewer()));
+connect(checkerAct, SIGNAL(triggered()), this, SLOT(checkSpellGrammarPage()));
 //connect( this, SIGNAL( backwardAvailable( bool ) ), historyBackAct, SLOT( setEnabled( bool ) ) );
 //connect( this, SIGNAL( forwardAvailable( bool ) ), historyForwardAct, SLOT( setEnabled( bool ) ) );
 }
@@ -592,6 +602,7 @@ disconnect(historyBackAct, SIGNAL(triggered()), this, SLOT(historyBack()));
 disconnect(historyForwardAct, SIGNAL(triggered()), this, SLOT(historyForward()));
 disconnect(printAct, SIGNAL(triggered()), this, SLOT(printPdf()));
 disconnect(externAct, SIGNAL(triggered()), this, SLOT(runExternalViewer()));
+disconnect(checkerAct, SIGNAL(triggered()), this, SLOT(checkSpellGrammarPage()));
 //disconnect( this, SIGNAL( backwardAvailable( bool ) ), historyBackAct, SLOT( setEnabled( bool ) ) );
 //disconnect( this, SIGNAL( forwardAvailable( bool ) ), historyForwardAct, SLOT( setEnabled( bool ) ) );
 }
@@ -1011,6 +1022,106 @@ if (fi.exists())
 	}
 }
 
+void PdfViewer::checkSpellGrammarPage()
+{
+if ((currentPage<1) || (currentPage>doc->numPages())) return;
+QString tempDir=QDir::tempPath();
+QString prefixFile=QDir::homePath();
+prefixFile="texmaker_temp_"+prefixFile.section('/',-1);
+prefixFile=QString(QUrl::toPercentEncoding(prefixFile));
+prefixFile.remove("%");
+QString tempFile=tempDir+"/"+prefixFile+".html";
+QTextCodec *codec = QTextCodec::codecForName("UTF-8");
+#if defined( Q_WS_X11 )
+#ifdef USB_VERSION
+QString atdloc=QCoreApplication::applicationDirPath()+"/";
+#else
+QString atdloc=PREFIX"/share/texmaker/";
+#endif
+#endif
+#if defined( Q_WS_MACX )
+QString atdloc=QCoreApplication::applicationDirPath() + "/../Resources/";
+#endif
+#if defined(Q_WS_WIN)
+QString atdloc=QCoreApplication::applicationDirPath() + "/";
+#endif
+QString pdf_text=doc->page(currentPage-1)->text(QRectF(),Poppler::Page::PhysicalLayout);
+QFile fi_html(tempFile);
+if (!fi_html.open(QIODevice::WriteOnly)) return;
+QTextStream out (&fi_html);
+out.setCodec(codec);
+out << "<html>\n";
+out << "<head>\n";
+out << "<title>Texmaker</title>\n";
+out << "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />\n";
+out << "<style>\n";
+out << ".input\n";
+out << "{\n";
+out << "width:90%;\n";
+out << "height:90%;\n";
+out << "border: 1px solid black;\n";
+out << "padding: 2px;\n";
+out << "margin: 2px;\n";
+out << "font-family: times;\n";
+out << "font-size: 80%;\n";
+out << "}\n";
+out << "</style>\n";
+out << "<script src=\"http://code.jquery.com/jquery-1.4.2.js\"></script>\n";
+out << "<script src=\"";
+out << atdloc;
+out << "/jquery.atd.textarea.js\"></script>\n";
+out << "<script src=\"";
+out << atdloc;
+out << "/csshttprequest.js\"></script>\n";
+out << "<link rel=\"stylesheet\" type=\"text/css\" media=\"screen\" href=\"";
+out << atdloc;
+out << "/atd.css\" />\n";
+out << "<script>\n";
+out << "function check() {\n";
+out << "AtD.rpc_css_lang = document.langform.langchoice.options[document.langform.langchoice.selectedIndex].text;\n";
+//out << atd_lang;
+//out << "';\n";
+out << "AtD.checkTextAreaCrossAJAX('textInput', 'checkLink', 'Click to reset');\n";
+out << " };\n";
+out << "</script>\n";
+out << "</head>\n";
+out << "<body BGCOLOR=\"#ffffff\">\n";
+out << "<textarea name=\"textInput\" id=\"textInput\" class=\"input\">\n";
+out << pdf_text;
+out << "</textarea>\n";
+out << "<form name=\"langform\">\n";
+out << "<p><a href=\"javascript:check()\" id=\"checkLink\">Click to check</a>&nbsp;&nbsp;\n";
+out << "<SELECT NAME=\"langchoice\">\n";
+bool done=false;
+if (spell_lang=="fr") {out << "<OPTION selected>fr</OPTION>\n"; done=true;}
+else out << "<OPTION>fr</OPTION>\n";
+if (spell_lang=="de") {out << "<OPTION selected>de</OPTION>\n"; done=true;}
+else out << "<OPTION>de</OPTION>\n";
+if (spell_lang=="nl") {out << "<OPTION selected>nl</OPTION>\n"; done=true;}
+else out << "<OPTION>nl</OPTION>\n";
+if (spell_lang=="pl") {out << "<OPTION selected>pl</OPTION>\n"; done=true;}
+else out << "<OPTION>pl</OPTION>\n";
+if (spell_lang=="pt") {out << "<OPTION selected>pt</OPTION>\n"; done=true;}
+else out << "<OPTION>pt</OPTION>\n";
+if (spell_lang=="ru") {out << "<OPTION selected>ru</OPTION>\n"; done=true;}
+else out << "<OPTION>ru</OPTION>\n";
+if (spell_lang=="it") {out << "<OPTION selected>it</OPTION>\n"; done=true;}
+else out << "<OPTION>it</OPTION>\n";
+if (spell_lang=="es") {out << "<OPTION selected>es</OPTION>\n"; done=true;}
+else out << "<OPTION>es</OPTION>\n";
+if ((spell_lang=="en") || (!done)) out << "<OPTION selected>en</OPTION>\n";
+else out << "<OPTION>en</OPTION>\n";
+out << "</SELECT></p></form>\n";
+out << "</body>\n";
+out << "</html>\n";
+fi_html.close();
+if (browserWindow) browserWindow->close();
+browserWindow=new Browser("file:///"+tempFile,false, 0);
+browserWindow->raise();
+browserWindow->show();
+
+}
+
 void PdfViewer::printPdf()
 {
 if (!fileLoaded) return;
