@@ -24,6 +24,8 @@
 #include <QSettings>
 #include <QTextStream>
 #include <QKeySequence>
+#include <QDesktopServices>
+#include <QTextCodec>
 
 
 #include "poppler-qt4.h"
@@ -31,9 +33,10 @@
 #define SYNCTEX_GZ_EXT ".synctex.gz"
 #define SYNCTEX_EXT ".synctex"
 
-PdfViewerWidget::PdfViewerWidget( const QString fileName, const QString externalCommand, const QString ghostscriptCommand, const QString psize,const QKeySequence edfocus,QWidget* parent)
+PdfViewerWidget::PdfViewerWidget( const QString fileName, const QString externalCommand, const QString ghostscriptCommand, const QString psize,const QKeySequence edfocus,const QString SpellLang ,QWidget* parent)
     : QWidget( parent)
 {
+spell_lang=SpellLang;
 KeySequenceEditorFocus=edfocus;
 canDisplayPixmap=false;
 pdf_file=fileName;
@@ -81,6 +84,7 @@ palette.setBrush(QPalette::Disabled, QPalette::Text, brush2);
 QBrush brush3(QColor(244, 244, 244, 255));
 brush3.setStyle(Qt::SolidPattern);
 palette.setBrush(QPalette::Disabled, QPalette::Base, brush3);
+palette.setColor( listpagesWidget->backgroundRole(), QColor( "#DEE4EB" ) );
 listpagesWidget->setPalette(palette);
 listpagesWidget->setAutoFillBackground( true );
 /*QPalette p( listpagesWidget->palette() );
@@ -136,8 +140,10 @@ zoomoutAct = new QAction(QIcon(":/images/zoom-out.png"), tr("Zoom Out"), this);
 zoomoutAct->setShortcut(QKeySequence::ZoomOut);
 centralToolBarBis->addAction(zoomoutAct);
 
+
 scaleComboBox = new QComboBox(centralToolBarBis);
 zoomCustom = new QLineEdit();
+
 //QValidator *validatorZoom = new QIntValidator(25, 400, this);
 QValidator *validatorZoom = new QRegExpValidator(QRegExp("\\d{0,3}%?"), this);
 zoomCustom->setValidator(validatorZoom);
@@ -152,6 +158,8 @@ centralToolBarBis->addWidget(scaleComboBox);
 centralToolBarBis->addSeparator();
 
 searchLineEdit = new QLineEdit(centralToolBarBis);
+
+
 centralToolBarBis->addWidget(searchLineEdit);
 
 findButton=new QPushButton(tr("Find"),centralToolBarBis);
@@ -183,7 +191,8 @@ centralToolBarBis->addAction(printAct);
 externAct = new QAction(QIcon(":/images/viewpdf.png"), tr("External Viewer"), this);
 centralToolBarBis->addAction(externAct);
 
-
+checkerAct = new QAction(QIcon(":/images/pdfchecker.png"), tr("Check Spelling and Grammar on this page"), this);
+centralToolBarBis->addAction(checkerAct);
 
 
 scrollArea=new PdfScrollArea(centralFrame);
@@ -246,6 +255,7 @@ connectActions();
 
 PdfViewerWidget::~PdfViewerWidget()
 {
+if (browserWindow) browserWindow->close();
 if (scanner != NULL) synctex_scanner_free(scanner);
 if (proc && proc->state()==QProcess::Running) 
 	{
@@ -326,7 +336,10 @@ if (doc!=0)
     lastFile=fn;
     setWindowTitle(QFileInfo(fn).fileName());
     clearHistory();
-    gotoPage(currentPage);   
+    gotoPage(currentPage);
+    disconnect(scrollArea,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
+    if (scrollArea->horizontalScrollBar()->isVisible())  scrollArea->horizontalScrollBar()->setValue(lastHpos);
+    connect(scrollArea,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
     } 
     else 
       {
@@ -543,6 +556,7 @@ connect(historyBackAct, SIGNAL(triggered()), this, SLOT(historyBack()));
 connect(historyForwardAct, SIGNAL(triggered()), this, SLOT(historyForward()));
 connect(printAct, SIGNAL(triggered()), this, SLOT(printPdf()));
 connect(externAct, SIGNAL(triggered()), this, SLOT(runExternalViewer()));
+connect(checkerAct, SIGNAL(triggered()), this, SLOT(checkSpellGrammarPage()));
 //connect( this, SIGNAL( backwardAvailable( bool ) ), historyBackAct, SLOT( setEnabled( bool ) ) );
 //connect( this, SIGNAL( forwardAvailable( bool ) ), historyForwardAct, SLOT( setEnabled( bool ) ) );
 }
@@ -570,6 +584,7 @@ disconnect(historyBackAct, SIGNAL(triggered()), this, SLOT(historyBack()));
 disconnect(historyForwardAct, SIGNAL(triggered()), this, SLOT(historyForward()));
 disconnect(printAct, SIGNAL(triggered()), this, SLOT(printPdf()));
 disconnect(externAct, SIGNAL(triggered()), this, SLOT(runExternalViewer()));
+disconnect(checkerAct, SIGNAL(triggered()), this, SLOT(checkSpellGrammarPage()));
 //disconnect( this, SIGNAL( backwardAvailable( bool ) ), historyBackAct, SLOT( setEnabled( bool ) ) );
 //disconnect( this, SIGNAL( forwardAvailable( bool ) ), historyForwardAct, SLOT( setEnabled( bool ) ) );
 }
@@ -990,6 +1005,107 @@ if (fi.exists())
 	}
 }
 
+void PdfViewerWidget::checkSpellGrammarPage()
+{
+if ((currentPage<1) || (currentPage>doc->numPages())) return;
+QString tempDir=QDir::tempPath();
+QString prefixFile=QDir::homePath();
+prefixFile="texmaker_temp_"+prefixFile.section('/',-1);
+prefixFile=QString(QUrl::toPercentEncoding(prefixFile));
+prefixFile.remove("%");
+QString tempFile=tempDir+"/"+prefixFile+".html";
+QTextCodec *codec = QTextCodec::codecForName("UTF-8");
+#if defined( Q_WS_X11 )
+#ifdef USB_VERSION
+QString atdloc=QCoreApplication::applicationDirPath()+"/";
+#else
+QString atdloc=PREFIX"/share/texmaker/";
+#endif
+#endif
+#if defined( Q_WS_MACX )
+QString atdloc=QCoreApplication::applicationDirPath() + "/../Resources/";
+#endif
+#if defined(Q_WS_WIN)
+QString atdloc=QCoreApplication::applicationDirPath() + "/";
+#endif
+QString pdf_text=doc->page(currentPage-1)->text(QRectF(),Poppler::Page::PhysicalLayout);
+QFile fi_html(tempFile);
+if (!fi_html.open(QIODevice::WriteOnly)) return;
+QTextStream out (&fi_html);
+out.setCodec(codec);
+out << "<html>\n";
+out << "<head>\n";
+out << "<title>Texmaker</title>\n";
+out << "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />\n";
+out << "<style>\n";
+out << ".input\n";
+out << "{\n";
+out << "width:90%;\n";
+out << "height:90%;\n";
+out << "border: 1px solid black;\n";
+out << "padding: 2px;\n";
+out << "margin: 2px;\n";
+out << "font-family: times;\n";
+out << "font-size: 80%;\n";
+out << "}\n";
+out << "</style>\n";
+out << "<script src=\"http://code.jquery.com/jquery-1.4.2.js\"></script>\n";
+out << "<script src=\"";
+out << atdloc;
+out << "/jquery.atd.textarea.js\"></script>\n";
+out << "<script src=\"";
+out << atdloc;
+out << "/csshttprequest.js\"></script>\n";
+out << "<link rel=\"stylesheet\" type=\"text/css\" media=\"screen\" href=\"";
+out << atdloc;
+out << "/atd.css\" />\n";
+out << "<script>\n";
+out << "function check() {\n";
+out << "AtD.rpc_css_lang = document.langform.langchoice.options[document.langform.langchoice.selectedIndex].text;\n";
+//out << atd_lang;
+//out << "';\n";
+out << "AtD.checkTextAreaCrossAJAX('textInput', 'checkLink', 'Click to reset');\n";
+out << " };\n";
+out << "</script>\n";
+out << "</head>\n";
+out << "<body BGCOLOR=\"#ffffff\">\n";
+out << "<textarea name=\"textInput\" id=\"textInput\" class=\"input\">\n";
+out << pdf_text;
+out << "</textarea>\n";
+out << "<form name=\"langform\">\n";
+out << "<p><a href=\"javascript:check()\" id=\"checkLink\">Click to check</a>&nbsp;&nbsp;\n";
+out << "<SELECT NAME=\"langchoice\">\n";
+bool done=false;
+if (spell_lang=="fr") {out << "<OPTION selected>fr</OPTION>\n"; done=true;}
+else out << "<OPTION>fr</OPTION>\n";
+if (spell_lang=="de") {out << "<OPTION selected>de</OPTION>\n"; done=true;}
+else out << "<OPTION>de</OPTION>\n";
+if (spell_lang=="nl") {out << "<OPTION selected>nl</OPTION>\n"; done=true;}
+else out << "<OPTION>nl</OPTION>\n";
+if (spell_lang=="pl") {out << "<OPTION selected>pl</OPTION>\n"; done=true;}
+else out << "<OPTION>pl</OPTION>\n";
+if (spell_lang=="pt") {out << "<OPTION selected>pt</OPTION>\n"; done=true;}
+else out << "<OPTION>pt</OPTION>\n";
+if (spell_lang=="ru") {out << "<OPTION selected>ru</OPTION>\n"; done=true;}
+else out << "<OPTION>ru</OPTION>\n";
+if (spell_lang=="it") {out << "<OPTION selected>it</OPTION>\n"; done=true;}
+else out << "<OPTION>it</OPTION>\n";
+if (spell_lang=="es") {out << "<OPTION selected>es</OPTION>\n"; done=true;}
+else out << "<OPTION>es</OPTION>\n";
+if ((spell_lang=="en") || (!done)) out << "<OPTION selected>en</OPTION>\n";
+else out << "<OPTION>en</OPTION>\n";
+out << "</SELECT></p></form>\n";
+out << "</body>\n";
+out << "</html>\n";
+fi_html.close();
+if (browserWindow) browserWindow->close();
+browserWindow=new Browser("file:///"+tempFile,false, 0);
+browserWindow->raise();
+browserWindow->show();
+
+
+}
+
 void PdfViewerWidget::printPdf()
 {
 if (!fileLoaded) return;
