@@ -45,6 +45,7 @@
 #include "minisplitter.h"
 #include "playerbutton.h"
 #include "symbollistwidget.h"
+#include "usertagslistwidget.h"
 #include "xmltagslistwidget.h"
 #include "logeditor.h"
 #include "hunspell/hunspell.hxx"
@@ -73,6 +74,7 @@ public:
 QString getName();
 QFont EditorFont;
 QByteArray windowstate,splitter1state,splitter2state,splitter3state,fullscreenstate;
+//virtual QMenu* createPopupMenu();
 
 public slots:
 void load( const QString &f );
@@ -107,6 +109,7 @@ LogEditor* OutputTextEdit;
 
 QStackedWidget *LeftPanelStackedWidget;
 QListWidget *OpenedFilesListWidget;
+UserTagsListWidget *usertagsListWidget;
 XmlTagsListWidget *MpListWidget, *PsListWidget, *leftrightWidget, *tikzWidget, *asyWidget;
 SymbolListWidget *RelationListWidget, *ArrowListWidget, *MiscellaneousListWidget, *DelimitersListWidget, *GreekListWidget, *MostUsedListWidget, *FavoriteListWidget;
 QTreeWidget *StructureTreeWidget;
@@ -118,7 +121,7 @@ QMenu *fileMenu, *recentMenu, *editMenu, *toolMenu;
 QMenu *latex1Menu, *latex11Menu, *latex12Menu, *latex13Menu, *latex14Menu, *latex15Menu, *latex16Menu, *latex17Menu, *latex18Menu ;
 QMenu *math1Menu, *math11Menu, *math12Menu, *math13Menu, *math14Menu;
 QMenu *wizardMenu;
-QMenu *bibMenu;
+QMenu *bibMenu, *bibtexMenu, *biblatexMenu;
 QMenu *user1Menu, *user11Menu, *user12Menu;
 QMenu *viewMenu;
 QMenu *optionsMenu, *translationMenu, *appearanceMenu, *settingsMenu;
@@ -126,6 +129,16 @@ QMenu *helpMenu;
 
 QToolBar *fileToolBar, *editToolBar, *runToolBar, *formatToolBar, *logToolBar, *LeftPanelToolBar,*LeftPanelToolBarBis, *centralToolBar, *centralToolBarBis;
 QAction *recentFileActs[10], *ToggleAct, *StopAct, *UndoAct, *RedoAct, *SaveAct, *CutAct, *CopyAct,*PasteAct, *ToggleDocAct, *ViewStructurePanelAct, *ViewLogPanelAct, *ViewPdfPanelAct, *ViewSourcePanelAct, *FullScreenAct, *NextDocAct, *PrevDocAct, *ViewOpenedFilesPanelAct ;
+
+QAction *relationAct, *arrowAct, *miscAct, *delimAct, *greekAct, *usedAct, *favAct, *leftrightAct, *pstricksAct, *mpAct, *tikzAct, *asyAct, *userpanelAct;
+bool showPstricks, showMp, showTikz, showAsy;
+QAction *viewPstricksAct, *viewMpAct, *viewTikzAct, *viewAsyAct;
+
+QAction *emphasisAct, *newlineAct, *mathmodeAct, *indiceAct, *puissanceAct, *smallfracAct, *dfracAct, *racineAct;
+QAction *showemphasisAct, *shownewlineAct, *showmathmodeAct, *showindiceAct, *showpuissanceAct, *showsmallfracAct, *showdfracAct, *showracineAct;
+bool showEmphasis, showNewline, showMathmode, showIndice, showPuissance, showSmallfrac, showDfrac, showRacine;
+
+
 QComboBox *comboCompil, *comboView, *comboFiles;
 QLabel *stat1, *stat2, *stat3, *titleLeftPanel, *posLabel;
 QPushButton *pb1, *pb2, *pb3;
@@ -139,11 +152,12 @@ bool eraseSettings, replaceSettings;
 QString settingsFileName;
 int split1_right, split1_left, split2_top, split2_bottom, quickmode, tabwidth;
 bool singlemode, wordwrap, parenmatch, showline, showoutputview, showstructview, showpdfview, showsourceview, showfilesview, ams_packages, makeidx_package, completion, inlinespellcheck, modern_style, new_gui, builtinpdfview, singleviewerinstance, babel_package, geometry_package, graphicx_package, watchfiles, autosave, tabspaces ;
+bool lmodern_package, kpfonts_package, fourier_package;
 QString document_class, typeface_size, paper_size, document_encoding, author, geometry_options, babel_default;
 QString latex_command, viewdvi_command, dvips_command, dvipdf_command, metapost_command, psize;
 QString viewps_command, ps2pdf_command, makeindex_command, bibtex_command, pdflatex_command, viewpdf_command, userquick_command, ghostscript_command, asymptote_command, latexmk_command, sweave_command, texdoc_command;
 QString spell_dic, spell_ignored_words;
-QString lastDocument, input_encoding, lastChild;
+QString lastDocument, input_encoding, lastChild, lastTemplate;
 QString struct_level1, struct_level2, struct_level3, struct_level4, struct_level5;
 QStringList userClassList, userPaperList, userEncodingList, userOptionsList, userCompletionList, userBabelList;
 QStringList labelitem, bibitem, listbibfiles, listchildfiles;
@@ -165,7 +179,7 @@ bool checkViewerInstance;
 QStringList errorFileList, errorTypeList, errorLineList, errorMessageList, errorLogList;
 QList<int> onlyErrorList;
 int errorIndex, runIndex, viewIndex;
-
+QString pdfCheckerLang;
 //X11
 #if defined( Q_WS_X11 )
 QString x11style;
@@ -175,10 +189,11 @@ int x11fontsize;
 SymbolList symbolScore;
 usercodelist symbolMostused;
 QList<int> favoriteSymbolList;
+QStringList userTagsList;
 
 QColor colorBackground, colorLine, colorHighlight, colorStandard, colorComment, colorMath, colorCommand, colorKeyword, colorVerbatim, colorTodo, colorKeywordGraphic, colorNumberGraphic;
 
-QList<QColor> edcolors() {QList<QColor> e; e << colorBackground << colorLine << colorHighlight ; return e;}
+QList<QColor> edcolors() {QList<QColor> e; e << colorBackground << colorLine << colorHighlight << colorStandard; return e;}
 QList<QColor> hicolors() {QList<QColor> h; h << colorStandard << colorComment << colorMath << colorCommand << colorKeyword << colorVerbatim << colorTodo << colorKeywordGraphic << colorNumberGraphic; return h;}
 
 QCompleter *completer;
@@ -264,16 +279,19 @@ void ShowLeftRight(); //leftrightWidget
 void ShowMplist(); //MpListWidget
 void ShowTikz(); //tikzWidget
 void ShowAsy(); //asyWidget
+void ShowUserPanel(); //userPanel
 void ClickedOnStructure(QTreeWidgetItem *item,int);
 
 void InsertTag(QString Entity, int dx, int dy);
 void InsertSymbol(QTableWidgetItem *item);
 void InsertXmlTag(QListWidgetItem *item);
+void InsertUserElement(QListWidgetItem *item);
 void InsertFromAction();
 void InsertWithSelectionFromAction();
 void InsertWithSelectionFromString(const QString& text);
 void InsertFromString(const QString& text);
 void InsertBib();
+void InsertBibLatex();
 void InsertStruct();
 void InsertStructFromString(const QString& text);
 void InsertImage();
@@ -293,6 +311,25 @@ void InsertBib10();
 void InsertBib11();
 void InsertBib12();
 void InsertBib13();
+
+void InsertBibLatex1(); //Article in Journal
+void InsertBibLatex2(); //Single-volume book
+void InsertBibLatex3(); //Multi-volume book
+void InsertBibLatex4(); //Part of a book
+void InsertBibLatex5(); //Booklet
+void InsertBibLatex6(); //Single-volume collection
+void InsertBibLatex7(); //Multi-volume collection
+void InsertBibLatex8(); //Part of a collection
+void InsertBibLatex9(); //Technical documentation
+void InsertBibLatex10(); //Miscellaneous
+void InsertBibLatex11(); //Online resource
+void InsertBibLatex12(); //Issue of a periodical
+void InsertBibLatex13(); //Single-volume conference proceedings
+void InsertBibLatex14(); //Multi-volume conference proceedings
+void InsertBibLatex15(); //Article in conference proceedings
+void InsertBibLatex16(); //Technical report
+void InsertBibLatex17(); //Thesis
+
 void CleanBib();
 
 void InsertUserTag(QString Entity);
@@ -324,7 +361,7 @@ void QuickDocument();
 void RunCommand(QString comd,bool waitendprocess);
 void readFromStderr();
 void stopProcess();
-//void readFromStdoutput();
+void readFromStdoutput();
 void SlotEndProcess(int err);
 void SlotEndViewerProcess(int err);
 void QuickBuild();
@@ -386,6 +423,8 @@ void SetMostUsedSymbols();
 void InsertFavoriteSymbols();
 void RemoveFavoriteSymbols();
 
+void RemoveUserTag();
+void AddUserTag();
 
 void ModifyShortcuts();
 
@@ -420,9 +459,26 @@ void addBibFiles(QString param);
 void addIncludeFiles(QString param);
 void loadIncludeFiles(QString param, QString extension);
 void showCursorPos(int li, int col);
+void customContentsMenuStructure( const QPoint &pos );
+void customContentsMenuMain( const QPoint &pos );
+void TogglePstricks();
+void ToggleMetapost();
+void ToggleTikz();
+void ToggleAsymptote();
+void ToggleEmphasis();
+void ToggleNewline();
+void ToggleMathmode();
+void ToggleIndice();
+void TogglePuissance();
+void ToggleSmallfrac();
+void ToggleDfrac();
+void ToggleRacine();
+void splitter2Changed();
+
 protected:
 void dragEnterEvent(QDragEnterEvent *event);
 void dropEvent(QDropEvent *event);
+void keyPressEvent(QKeyEvent * event);
 virtual void changeEvent(QEvent *e);
 
 signals:
