@@ -15,6 +15,25 @@
         <translation>Új</translation>
     </message>
 </context>
+<context>
+    <name>AddTagDialog</name>
+    <message>
+        <source>Edit User Tags</source>
+        <translation type="unfinished">Felhasználói sablonok szerkesztése</translation>
+    </message>
+    <message>
+        <source>Item</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LaTeX Content</source>
+        <translation type="unfinished">LaTeX tartalom</translation>
+    </message>
+    <message>
+        <source>Keyboard Trigger</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ArrayDialog</name>
     <message>
@@ -261,7 +280,7 @@
     </message>
     <message>
         <source>Get dictionary at: %1</source>
-        <translation>Szótár letöltése innen: %1</translation>
+        <translation type="obsolete">Szótár letöltése innen: %1</translation>
     </message>
     <message>
         <source>Commands</source>
@@ -467,6 +486,10 @@ az alapértelmezett kódolási beállítással</translation>
         <source>Select a File</source>
         <translation>Válasszon egy fájlt</translation>
     </message>
+    <message>
+        <source>Center</source>
+        <translation type="unfinished">Középre</translation>
+    </message>
 </context>
 <context>
     <name>KeySequenceDialog</name>
@@ -706,6 +729,10 @@ az alapértelmezett kódolási beállítással</translation>
         <source>Can&apos;t print : the ghostscript command (gswin32c.exe) was not found on your system.</source>
         <translation>Nem sikerült nyomtatni : a ghostscript parancs (gswin32c.exe) nem található a rendszerén.</translation>
     </message>
+    <message>
+        <source>Check Spelling and Grammar on this page</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PdfViewerWidget</name>
@@ -769,6 +796,10 @@ az alapértelmezett kódolási beállítással</translation>
         <source>Can&apos;t print : the ghostscript command (gswin32c.exe) was not found on your system.</source>
         <translation>Nem sikerült nyomtatni : a ghostscript parancs (gswin32c.exe) nem található a rendszerén.</translation>
     </message>
+    <message>
+        <source>Check Spelling and Grammar on this page</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -887,6 +918,18 @@ az alapértelmezett kódolási beállítással</translation>
         <source>graphicx Package</source>
         <translation>graphicx csomag</translation>
     </message>
+    <message>
+        <source>lmodern Package</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Kpfonts Package</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Fourier Package</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RefDialog</name>
@@ -1321,7 +1364,7 @@ az alapértelmezett kódolási beállítással</translation>
     </message>
     <message>
         <source>Underline</source>
-        <translation>Aláhúzott</translation>
+        <translation type="obsolete">Aláhúzott</translation>
     </message>
     <message>
         <source>Left</source>
@@ -1924,6 +1967,10 @@ az alapértelmezett kódolási beállítással</translation>
 (.log,.aux,.dvi,.lof,.lot,.bit,.idx,.glo,.bbl,.ilg,.toc,.ind,.out,.synctex.gz,.blg,.thm,.pre)</source>
         <translation></translation>
     </message>
+    <message>
+        <source>User</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UserCompletionDialog</name>
@@ -1998,6 +2045,17 @@ az alapértelmezett kódolási beállítással</translation>
         <translation>Törlés</translation>
     </message>
 </context>
+<context>
+    <name>UserTagsListWidget</name>
+    <message>
+        <source>Add tag</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>UserToolDialog</name>
     <message>
